==> cloudcompare_2.10.3.orig.tar.gz: CloudCompare-2.10.3/ccViewer/ccViewerApplication.h <==
#ifndef CCVIEWERAPPLICATION_H
#define CCVIEWERAPPLICATION_H

//##########################################################################
//#                                                                        #
//#                              CLOUDCOMPARE                              #
//#                                                                        #
//#  This program is free software; you can redistribute it and/or modify  #
//#  it under the terms of the GNU General Public License as published by  #
//#  the Free Software Foundation; version 2 or later of the License.      #
//#                                                                        #
//#  This program is distributed in the hope that it will be useful,       #
//#  but WITHOUT ANY WARRANTY; without even the implied warranty of        #
//#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          #
//#  GNU General Public License for more details.                          #
//#                                                                        #
//#          COPYRIGHT: CloudCompare project                               #
//#                                                                        #
//##########################################################################

//Common
#include <ccApplicationBase.h>

class ccViewer;

class ccViewerApplication : public ccApplicationBase
{
	Q_OBJECT
	
public:
	ccViewerApplication( int &argc, char **argv );

	void  setViewer( ccViewer *inViewer );
	
protected:
	bool event( QEvent *inEvent ) override;
	
private:
	ccViewer *mViewer;
};

#endif

==> cloudcompare_2.11.3.orig.tar.gz: CloudCompare-2.11.3/ccViewer/ccViewerApplication.h <==
#ifndef CCVIEWERAPPLICATION_H
#define CCVIEWERAPPLICATION_H

//##########################################################################
//#                                                                        #
//#                              CLOUDCOMPARE                              #
//#                                                                        #
//#  This program is free software; you can redistribute it and/or modify  #
//#  it under the terms of the GNU General Public License as published by  #
//#  the Free Software Foundation; version 2 or later of the License.      #
//#                                                                        #
//#  This program is distributed in the hope that it will be useful,       #
//#  but WITHOUT ANY WARRANTY; without even the implied warranty of        #
//#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          #
//#  GNU General Public License for more details.                          #
//#                                                                        #
//#          COPYRIGHT: CloudCompare project                               #
//#                                                                        #
//##########################################################################

//Common
#include <ccApplicationBase.h>

class ccViewer;

class ccViewerApplication : public ccApplicationBase
{
	Q_OBJECT
	
public:
	ccViewerApplication( int &argc, char **argv, bool isCommandLine );

	void  setViewer( ccViewer *inViewer );
	
protected:
	bool event( QEvent *inEvent ) override;
	
private:
	ccViewer *mViewer;
};

#endif
